searchData={"items":[{"type":"module","title":"Toast","doc":"Server-rendered toast notifications for Phoenix LiveView.\n\nThis module provides the main API for sending toast notifications\nthat are managed server-side using LiveView streams.","ref":"Toast.html"},{"type":"function","title":"Toast.clear_all_toasts/0","doc":"Clears all toasts.","ref":"Toast.html#clear_all_toasts/0"},{"type":"function","title":"Toast.clear_toast/1","doc":"Clears a specific toast by ID.","ref":"Toast.html#clear_toast/1"},{"type":"function","title":"Toast.put_toast/4","doc":"Sends a toast notification and updates the flash.\nUsed for toasts that should persist across live navigation.","ref":"Toast.html#put_toast/4"},{"type":"function","title":"Toast.send_toast/3","doc":"Sends a toast notification to the LiveComponent.","ref":"Toast.html#send_toast/3"},{"type":"function","title":"Examples - Toast.send_toast/3","doc":"LiveToast.send_toast(:info, \"Operation completed!\")\n    LiveToast.send_toast(:error, \"Something went wrong\", title: \"Error\", duration: 10_000)","ref":"Toast.html#send_toast/3-examples"},{"type":"type","title":"Toast.t/0","doc":"","ref":"Toast.html#t:t/0"},{"type":"function","title":"Toast.update_toast/2","doc":"Updates an existing toast by ID.","ref":"Toast.html#update_toast/2"},{"type":"function","title":"Examples - Toast.update_toast/2","doc":"Toast.update_toast(\"toast-123\", message: \"Updated message\", type: :success)\n    Toast.update_toast(\"toast-123\", title: \"New Title\", duration: 10_000)","ref":"Toast.html#update_toast/2-examples"},{"type":"module","title":"Toast.Components","doc":"Toast UI components for LiveToast.","ref":"Toast.Components.html"},{"type":"function","title":"Toast.Components.container/1","doc":"Renders the container component that can render flash messages as toasts.","ref":"Toast.Components.html#container/1"},{"type":"function","title":"Attributes - Toast.Components.container/1","doc":"* `flash` (`:map`) - Defaults to `%{}`.\n* `position` (`:string`) - Defaults to `\"bottom-right\"`.\n* `theme` (`:string`) - Defaults to `\"light\"`.\n* `rich_colors` (`:boolean`) - Defaults to `false`.\n* `id` (`:string`) - Defaults to `\"toast-group\"`.\n* `max_toasts` (`:integer`) - Defaults to `nil`.","ref":"Toast.Components.html#container/1-attributes"},{"type":"function","title":"Toast.Components.toast/1","doc":"Renders an individual toast notification.","ref":"Toast.Components.html#toast/1"},{"type":"function","title":"Attributes - Toast.Components.toast/1","doc":"* `toast` (`Toast`) (required)","ref":"Toast.Components.html#toast/1-attributes"},{"type":"module","title":"Toast.LiveComponent","doc":"","ref":"Toast.LiveComponent.html"},{"type":"extras","title":"SimpleToast","doc":"# SimpleToast\n\nDead simple toast notifications for Phoenix LiveView. No CSS imports, no npm, just works.","ref":"readme.html"},{"type":"extras","title":"Installation - SimpleToast","doc":"1. Add `simple_toast` to your dependencies:\n\n```elixir\ndef deps do\n  [\n    {:simple_toast, \"~> 0.1.0\"}\n  ]\nend\n```\n\n2. Import the JavaScript hook in your `app.js`:\n\n```javascript\nimport { SimpleToast } from \"simple_toast\";\n\n// Add to your hooks\nlet hooks = {\n  // ... your other hooks\n  SimpleToast: SimpleToast\n};\n```\n\n3. Add the container to your root layout (e.g., `root.html.heex`):\n\n```heex\n \n```\n\nThat's it! No CSS imports needed - styles are injected automatically.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - SimpleToast","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"In LiveView - SimpleToast","doc":"```elixir\ndef handle_event(\"save\", _params, socket) do\n  # Your save logic here...\n  \n  {:noreply, SimpleToast.send(socket, :success, \"Changes saved!\")}\nend\n\ndef handle_event(\"delete\", _params, socket) do\n  # Your delete logic here...\n  \n  {:noreply, SimpleToast.send(socket, :error, \"Failed to delete\", duration: 5000)}\nend\n```","ref":"readme.html#in-liveview"},{"type":"extras","title":"In Controllers - SimpleToast","doc":"```elixir\ndef create(conn, params) do\n  # Your create logic here...\n  \n  conn\n  |> SimpleToast.put_flash(:success, \"Item created successfully!\")\n  |> redirect(to: ~p\"/items\")\nend\n```","ref":"readme.html#in-controllers"},{"type":"extras","title":"Toast Types - SimpleToast","doc":"- `:info` - Blue toast for informational messages\n- `:success` - Green toast for success messages  \n- `:error` - Red toast for error messages\n- `:warning` - Yellow toast for warning messages","ref":"readme.html#toast-types"},{"type":"extras","title":"Options - SimpleToast","doc":"- `:duration` - How long to show the toast in milliseconds (default: 3000)","ref":"readme.html#options"},{"type":"extras","title":"Why SimpleToast? - SimpleToast","doc":"Unlike other toast libraries, SimpleToast:\n\n- **No CSS imports** - All styles are bundled inline\n- **No JavaScript setup** - The hook is automatically injected\n- **No npm dependencies** - Pure Elixir/Phoenix solution\n- **No configuration** - Works out of the box\n- **Minimal API** - Just `send/3` and `put_flash/3`\n- **Tiny footprint** - Single component, no bloat","ref":"readme.html#why-simpletoast"},{"type":"extras","title":"License - SimpleToast","doc":"MIT License. See LICENSE for details.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}